ford package
============

.. automodule:: ford
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   ford.fixed2free2
   ford.fortran_project
   ford.graphs
   ford.intrinsics
   ford.md_environ
   ford.md_striped_table
   ford.output
   ford.pagetree
   ford.reader
   ford.sourceform
   ford.tipue_search
   ford.utils
